schemetools.SchemeColor
=======================

.. abjad-lineage:: abjad.tools.schemetools.SchemeColor.SchemeColor.SchemeColor

.. autoclass:: abjad.tools.schemetools.SchemeColor.SchemeColor.SchemeColor
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.schemetools.SchemeColor.SchemeColor.SchemeColor.force_quotes
   :noindex:

.. autoattribute:: abjad.tools.schemetools.SchemeColor.SchemeColor.SchemeColor.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.schemetools.SchemeColor.SchemeColor.SchemeColor.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.schemetools.SchemeColor.SchemeColor.SchemeColor.__eq__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemeColor.SchemeColor.SchemeColor.__ge__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemeColor.SchemeColor.SchemeColor.__gt__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemeColor.SchemeColor.SchemeColor.__le__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemeColor.SchemeColor.SchemeColor.__lt__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemeColor.SchemeColor.SchemeColor.__ne__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemeColor.SchemeColor.SchemeColor.__repr__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemeColor.SchemeColor.SchemeColor.__str__
   :noindex:
